/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ProcessLog.java 3054 2008-04-30 15:41:13Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.osgi.plugins.launcher;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;

import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Allows to trace errors/output of a process.
 */
public class ProcessLog implements Runnable {

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(ProcessLog.class);

    /**
     * Input stream containing information.
     */
    private InputStream is;

    /**
     * Should send as error or debug message ?
     */
    private boolean isErrorMessage = false;

    /**
     * Constructor.
     * @param is given input stream
     * @param isErrorMessage Should send as error or debug message
     */
    public ProcessLog(final InputStream is, final boolean isErrorMessage) {
        this.is = is;
        this.isErrorMessage = isErrorMessage;
    }

    /**
     * Thread execution printing information received.
     */
    public void run() {
        try {
            BufferedReader br = new BufferedReader(new InputStreamReader(is));
            String str = null;
            while ((str = br.readLine()) != null) {
                if (isErrorMessage) {
                    logger.error("RemoteJVM: {0}", str);
                } else {
                    logger.info("RemoteJVM: {0}", cleanup(str));
                }
            }
            // close input stream
            is.close();
        } catch (Exception e) {
            logger.error("Cannot close stream", e);
        }
    }

    /**
     * Cleanup the given string by removing the beginning of the message if it is a known info message.
     * @param string the string to cleanup
     * @return the cleaned string
     */
    public String cleanup(final String string) {
        // If it contains " (I) ", remove the first arguments
        String updatedString = string;
        String infoLevel = " (I) ";
        int index = string.indexOf(infoLevel);
        if (index != -1) {
            updatedString = string.substring(index + infoLevel.length());
        }

        return updatedString;
    }

}
